pychemia.core package
=====================

.. automodule:: pychemia.core
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pychemia.core.tests

Submodules
----------

pychemia.core.composition module
--------------------------------

.. automodule:: pychemia.core.composition
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.core.delaunay module
-----------------------------

.. automodule:: pychemia.core.delaunay
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.core.from_file module
------------------------------

.. automodule:: pychemia.core.from_file
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.core.structure module
------------------------------

.. automodule:: pychemia.core.structure
    :members:
    :undoc-members:
    :show-inheritance:


